from bokeh.io import output_notebook

class Session:
    def __init__(self, width=300, height=300, jupyter_notebook=False):
        self.width = width
        self.height = height
        if jupyter_notebook:
            output_notebook()



import setuptools

with open("README.md", "r") as fh:
    long_description = fh.read()

setuptools.setup(
    name="depict", # Replace with your own username
    version="0.0.5",
    author="Victor Boulanger",
    author_email="vb@live.fr",
    description="Business grade plots in seconds",
    long_description=long_description,
    long_description_content_type="text/markdown",
    url="https://github.com/vboulanger/depict",
    packages=setuptools.find_packages(),
    classifiers=[
        "Programming Language :: Python :: 3",
        "License :: OSI Approved :: GNU Affero General Public License v3",
        "Operating System :: OS Independent",
        "Development Status :: 2 - Pre-Alpha",
        "Natural Language :: English",
        "Topic :: Scientific/Engineering :: Visualization",
    ],
    python_requires='>=3.6',
)




from bokeh.plotting import figure
from bokeh.io import show


def line(y, x=None):
    """ One dimensional plot

    Args:
        x (array-like): X-axis data
        y (array-like): y-axis data
    """
    if x is None:
        y = np.arange(len(y))
    plot = figure()
    plot.line(x=x, y=y)
    show(plot)